# boxicons-filled

bx-8-ball
bx-a-arrow-down
bx-a-arrow-up
bx-accessibility
bx-acorn
bx-address-book
bx-air-conditioner
bx-air
bx-airplay
bx-alarm-alt
bx-alarm-check
bx-alarm-exclamation
bx-alarm-minus
bx-alarm-plus
bx-alarm-slash
bx-alarm-z
bx-alarm
bx-album-covers
bx-alert-circle
bx-alert-octagon
bx-alert-shield
bx-alert-square
bx-alert-triangle
bx-alien
bx-align-center
bx-align-horizontal-justify-center
bx-align-horizontal-justify-end
bx-align-horizontal-justify-start
bx-align-horizontal-space-between
bx-align-justify
bx-align-left
bx-align-right
bx-align-vertical-justify-center
bx-align-vertical-justify-end
bx-align-vertical-justify-start
bx-align-vertical-space-between
bx-ambulance
bx-ampersand
bx-analyze
bx-anchor
bx-angle
bx-angry
bx-animation-bounce
bx-announcement
bx-apartment
bx-apple-full
bx-approximate
bx-apps-alt
bx-apps
bx-arch
bx-archive-alt
bx-archive-arrow-down
bx-archive-arrow-up
bx-archive
bx-area
bx-arrow-big-down-line
bx-arrow-big-down
bx-arrow-big-left-line
bx-arrow-big-left
bx-arrow-big-right-line
bx-arrow-big-right
bx-arrow-big-up-line
bx-arrow-big-up
bx-arrow-cross
bx-arrow-down-a-z
bx-arrow-down-circle
bx-arrow-down-left-circle
bx-arrow-down-left-square
bx-arrow-down-left-stroke-circle
bx-arrow-down-left-stroke-square
bx-arrow-down-left-stroke
bx-arrow-down-left
bx-arrow-down-narrow-wide
bx-arrow-down-right-circle
bx-arrow-down-right-square
bx-arrow-down-right-stroke-circle
bx-arrow-down-right-stroke-square
bx-arrow-down-right-stroke
bx-arrow-down-right
bx-arrow-down-square
bx-arrow-down-stroke-circle
bx-arrow-down-stroke-square
bx-arrow-down-stroke
bx-arrow-down-up
bx-arrow-down-wide-narrow
bx-arrow-down
bx-arrow-from-bottom-stroke
bx-arrow-from-bottom
bx-arrow-from-left-stroke
bx-arrow-from-left
bx-arrow-from-right-stroke
bx-arrow-from-right
bx-arrow-from-top-stroke
bx-arrow-from-top
bx-arrow-in-down-circle-half
bx-arrow-in-down-left-circle
bx-arrow-in-down-left-square
bx-arrow-in-down-left-stroke-circle
bx-arrow-in-down-left-stroke-square
bx-arrow-in-down-right-circle
bx-arrow-in-down-right-square
bx-arrow-in-down-right-stroke-circle
bx-arrow-in-down-right-stroke-square
bx-arrow-in-down-square-half
bx-arrow-in-down-stroke-circle-half
bx-arrow-in-left-circle-half
bx-arrow-in-left-square-half
bx-arrow-in-left-stroke-circle-half
bx-arrow-in-right-circle-half
bx-arrow-in-right-square-half
bx-arrow-in-right-stroke-circle-half
bx-arrow-in-up-circle-half
bx-arrow-in-up-left-circle
bx-arrow-in-up-left-square
bx-arrow-in-up-left-stroke-circle
bx-arrow-in-up-left-stroke-square
bx-arrow-in-up-right-circle
bx-arrow-in-up-right-square
bx-arrow-in-up-right-stroke-circle
bx-arrow-in-up-right-stroke-square
bx-arrow-in-up-square-half
bx-arrow-in-up-stroke-circle-half
bx-arrow-left-circle
bx-arrow-left-right
bx-arrow-left-square
bx-arrow-left-stroke-circle
bx-arrow-left-stroke-square
bx-arrow-left-stroke
bx-arrow-left
bx-arrow-out-down-circle-half
bx-arrow-out-down-left-circle
bx-arrow-out-down-left-square
bx-arrow-out-down-left-stroke-circle
bx-arrow-out-down-left-stroke-square
bx-arrow-out-down-right-circle
bx-arrow-out-down-right-square
bx-arrow-out-down-right-stroke-circle
bx-arrow-out-down-right-stroke-square
bx-arrow-out-down-square-half
bx-arrow-out-down-stroke-circle-half
bx-arrow-out-left-circle-half
bx-arrow-out-left-square-half
bx-arrow-out-left-stroke-circle-half
bx-arrow-out-right-circle-half
bx-arrow-out-right-square-half
bx-arrow-out-right-stroke-circle-half
bx-arrow-out-up-circle-half
bx-arrow-out-up-left-circle
bx-arrow-out-up-left-square
bx-arrow-out-up-left-stroke-circle
bx-arrow-out-up-left-stroke-square
bx-arrow-out-up-right-circle
bx-arrow-out-up-right-square
bx-arrow-out-up-right-stroke-circle
bx-arrow-out-up-right-stroke-square
bx-arrow-out-up-square-half
bx-arrow-out-up-stroke-circle-half
bx-arrow-right-circle
bx-arrow-right-left
bx-arrow-right-square
bx-arrow-right-stroke-circle
bx-arrow-right-stroke-square
bx-arrow-right-stroke
bx-arrow-right
bx-arrow-s-down
bx-arrow-s-left
bx-arrow-s-right
bx-arrow-s-up
bx-arrow-to-bottom-stroke
bx-arrow-to-bottom
bx-arrow-to-left-stroke
bx-arrow-to-left
bx-arrow-to-right-stroke
bx-arrow-to-right
bx-arrow-to-top-stroke
bx-arrow-to-top
bx-arrow-up-a-z
bx-arrow-up-circle
bx-arrow-up-down
bx-arrow-up-left-circle
bx-arrow-up-left-square
bx-arrow-up-left-stroke-circle
bx-arrow-up-left-stroke-square
bx-arrow-up-left-stroke
bx-arrow-up-left
bx-arrow-up-narrow-wide
bx-arrow-up-right-circle
bx-arrow-up-right-square
bx-arrow-up-right-stroke-circle
bx-arrow-up-right-stroke-square
bx-arrow-up-right-stroke
bx-arrow-up-right
bx-arrow-up-square
bx-arrow-up-stroke-circle
bx-arrow-up-stroke-square
bx-arrow-up-stroke
bx-arrow-up-wide-narrow
bx-arrow-up
bx-article
bx-asterisk
bx-at
bx-atom
bx-avocado
bx-axe
bx-background-color-fill
bx-background
bx-backpack-star
bx-backpack
bx-backspace
bx-backward-slash
bx-bacon
bx-bacteria
bx-badge-check
bx-badge-exclamation
bx-badge-info
bx-badge
bx-baguette
bx-bahai
bx-balcony
bx-ball-throw
bx-balloon
bx-band-aid
bx-bank
bx-bar-chart-big
bx-bar-chart-square
bx-bar-chart
bx-barcode-square
bx-barcode
bx-barn
bx-baseball
bx-basket
bx-basketball
bx-bath
bx-battery-1
bx-battery-2
bx-battery-3
bx-battery-full
bx-battery-low
bx-battery
bx-beach-ball
bx-beach
bx-beaker
bx-beanie
bx-bear
bx-bed-alt
bx-bed
bx-beer
bx-bell-check
bx-bell-minus
bx-bell-plus
bx-bell-ring
bx-bell-slash
bx-bell
bx-bench
bx-between-horizontal-end
bx-between-horizontal-start
bx-between-vertical-end
bx-between-vertical-start
bx-bible
bx-biceps
bx-binocular
bx-bird-alt
bx-bird
bx-birthday-cake
bx-bitcoin
bx-blanket
bx-blob
bx-block
bx-blockquote
bx-blocks
bx-bluetooth
bx-blur-alt
bx-blur
bx-body
bx-bold
bx-bolt-alt
bx-bolt-circle
bx-bolt-square
bx-bolt
bx-bomb
bx-bone
bx-bong
bx-book-add
bx-book-alt
bx-book-bookmark
bx-book-content
bx-book-heart
bx-book-library
bx-book-open
bx-book
bx-bookmark-alt
bx-bookmark-heart
bx-bookmark-minus-alt
bx-bookmark-minus
bx-bookmark-plus-alt
bx-bookmark-plus
bx-bookmark-star
bx-bookmark-x
bx-bookmark
bx-bookmarks
bx-boombox
bx-boot
bx-border-all
bx-border-bottom
bx-border-inner
bx-border-left
bx-border-none
bx-border-outer
bx-border-radius
bx-border-right
bx-border-top
bx-bow
bx-bowl-balls
bx-bowl-bubbles
bx-bowl-hot
bx-bowl-noodles-alt
bx-bowl-noodles
bx-bowl-rice
bx-bowling-ball
bx-box-alt
bx-box
bx-bracket-curly
bx-bracket-round
bx-bracket
bx-braille
bx-brain-circuit
bx-brain
bx-bread
bx-brick
bx-bridge
bx-briefcase-alt-2
bx-briefcase-alt
bx-briefcase
bx-brightness-half
bx-brightness
bx-broadcast
bx-broccoli
bx-broom
bx-browser-activity
bx-brush-sparkles
bx-brush
bx-bucket
bx-buddhism
bx-bug-alt
bx-bug
bx-building-hospital
bx-building-house
bx-building-small
bx-building
bx-buildings
bx-bullseye
bx-buoy
bx-burger-alt
bx-burger
bx-bus
bx-business
bx-butterfly
bx-button-rounded
bx-button
bx-cabinet
bx-cable-car
bx-cake-slice
bx-calculator
bx-calendar-alt-2
bx-calendar-alt
bx-calendar-check
bx-calendar-cog
bx-calendar-detail
bx-calendar-down-arrow
bx-calendar-event
bx-calendar-heart
bx-calendar-minus
bx-calendar-plus
bx-calendar-search
bx-calendar-star
bx-calendar-up-arrow
bx-calendar-week
bx-calendar-x
bx-calendar
bx-camcoder
bx-camera-alt
bx-camera-flip
bx-camera-home
bx-camera-monochrome
bx-camera-plus
bx-camera-portrait
bx-camera-slash
bx-camera-switch
bx-camera
bx-campfire
bx-camping
bx-candlestick
bx-cannabis
bx-cap
bx-capitalize
bx-capsule
bx-captions-cc
bx-captions
bx-capture
bx-car-battery
bx-car-bolt
bx-car-key
bx-car-sparkles
bx-car
bx-card-view-large
bx-card-view-no-title
bx-card-view-small
bx-card-view-tiles
bx-card-view
bx-caret-big-down
bx-caret-big-left
bx-caret-big-right
bx-caret-big-up
bx-caret-down-circle
bx-caret-down-square
bx-caret-down
bx-caret-left-circle
bx-caret-left-square
bx-caret-left
bx-caret-right-circle
bx-caret-right-square
bx-caret-right
bx-caret-up-circle
bx-caret-up-square
bx-caret-up
bx-carets-down-up
bx-carets-left-right
bx-carets-right-left
bx-carets-up-down
bx-carrot
bx-cart-alt-2
bx-cart-alt
bx-cart-check
bx-cart-minus
bx-cart-plus
bx-cart-x
bx-cart
bx-cast
bx-castle
bx-cat-body
bx-cat
bx-categories
bx-cctv
bx-certification
bx-chair
bx-champagne
bx-chart-area
bx-chart-bar-big-columns
bx-chart-bar-big-rows
bx-chart-bar-columns
bx-chart-bar-rows
bx-chart-bubble
bx-chart-gantt
bx-chart-line
bx-chart-network
bx-chart-scatter
bx-chart-sine
bx-chart-spline
bx-chart-stacked-columns
bx-chart-stacked-rows
bx-chart-trend
bx-chart-waterfall
bx-check-circle
bx-check-shield
bx-check-square
bx-check
bx-checkbox-checked
bx-checkbox-square
bx-checkbox
bx-checklist
bx-checks
bx-cheese
bx-chef-hat
bx-cherry
bx-chess-bishop
bx-chess-king
bx-chess-knight
bx-chess-pawn
bx-chess-queen
bx-chess-rook
bx-chess
bx-chevron-down-circle
bx-chevron-down-square
bx-chevron-down
bx-chevron-left-circle
bx-chevron-left-square
bx-chevron-left
bx-chevron-right-circle
bx-chevron-right-square
bx-chevron-right
bx-chevron-up-circle
bx-chevron-up-square
bx-chevron-up
bx-chevrons-down-up
bx-chevrons-down
bx-chevrons-left-right
bx-chevrons-left
bx-chevrons-right-left
bx-chevrons-right
bx-chevrons-up-down
bx-chevrons-up
bx-child
bx-chip
bx-christianity
bx-church
bx-cigarette
bx-circle-dashed-half
bx-circle-dashed
bx-circle-half-alt
bx-circle-half
bx-circle-hexagon
bx-circle-outer-dashed-circle
bx-circle-quarter-alt
bx-circle-quarter
bx-circle-three-quarter-alt
bx-circle-three-quarter
bx-circle
bx-circles-9
bx-circles-alt
bx-circles
bx-circuit-board
bx-city
bx-clipboard-check
bx-clipboard-code
bx-clipboard-detail
bx-clipboard-minus
bx-clipboard-plus
bx-clipboard-x
bx-clipboard
bx-clock-1
bx-clock-10
bx-clock-11
bx-clock-12
bx-clock-2
bx-clock-3
bx-clock-4
bx-clock-5
bx-clock-6
bx-clock-7
bx-clock-8
bx-clock-9
bx-clock-dashed-half
bx-clock
bx-cloud-alt-2
bx-cloud-alt
bx-cloud-drizzle
bx-cloud-fog
bx-cloud-lightning
bx-cloud-moon
bx-cloud-rain-wind-alt
bx-cloud-rain-wind
bx-cloud-rain
bx-cloud-snow
bx-cloud-sun
bx-cloud
bx-clover
bx-club
bx-cocktail
bx-code-alt
bx-code
bx-coffee-beans
bx-coffee-cup
bx-coffee
bx-cog
bx-cognition
bx-coin
bx-coins
bx-col-resize
bx-color-fill
bx-color-wheel
bx-columns-3
bx-columns-4
bx-columns
bx-comic-bubble
bx-command
bx-community
bx-compare-alt
bx-compare
bx-compass-tool
bx-compass
bx-component
bx-computer-retro
bx-computer
bx-confused
bx-connector
bx-contact-book
bx-container
bx-contrast
bx-cookie
bx-cool
bx-copy-check
bx-copy-list
bx-copy-minus
bx-copy-plus
bx-copy-x
bx-copy
bx-copyright
bx-core
bx-couch
bx-credit-card-alt
bx-credit-card-front
bx-credit-card-insert
bx-credit-card
bx-cricket-ball
bx-crop
bx-cross-circle
bx-crosshair
bx-crown
bx-crypto-coin
bx-crypto
bx-cube-alt
bx-cube-inside
bx-cube
bx-cuboid
bx-cup-hot
bx-cup-saucer
bx-cup-tea
bx-cup
bx-cupboard-alt
bx-cupboard
bx-cupcake
bx-currency-note
bx-currency-notes
bx-cursor-add
bx-cursor-cell
bx-cursor-click
bx-cursor-crosshair-dot
bx-cursor-crosshair
bx-cursor-pen
bx-cursor-pointer
bx-cursor
bx-cut
bx-cycling
bx-cylinder
bx-dashboard-alt
bx-dashboard
bx-database-alt
bx-database
bx-decrease-indent
bx-delta
bx-department-store
bx-desert
bx-desk
bx-desktop-alt
bx-desktop
bx-devices
bx-dialpad
bx-diameter
bx-diamond-alt
bx-diamond
bx-diamonds
bx-dice-1
bx-dice-2
bx-dice-3
bx-dice-4
bx-dice-5
bx-dice-6
bx-dice-roll
bx-dino
bx-directions
bx-disc
bx-discount
bx-discussion
bx-dish
bx-dishwasher
bx-dislike
bx-division
bx-dizzy
bx-dna
bx-dock-bottom-alt
bx-dock-bottom-arrow
bx-dock-bottom-left-alt
bx-dock-bottom-left
bx-dock-bottom-right-alt
bx-dock-bottom-right
bx-dock-bottom
bx-dock-left-alt
bx-dock-left-arrow
bx-dock-left
bx-dock-right-alt
bx-dock-right-arrow
bx-dock-right
bx-dock-top-alt
bx-dock-top-arrow
bx-dock-top-left-alt
bx-dock-top-left
bx-dock-top-right-alt
bx-dock-top-right
bx-dock-top
bx-dog-alt
bx-dog-body
bx-dog
bx-dollar-circle-stars
bx-dollar-circle
bx-dollar
bx-donate-blood
bx-donate-heart
bx-donut
bx-door-open-alt
bx-door-open
bx-door
bx-dots-horizontal-rounded-circle
bx-dots-horizontal-rounded
bx-dots-horizontal
bx-dots-vertical-rounded-circle
bx-dots-vertical-rounded
bx-dots-vertical
bx-doughnut-chart
bx-draw-ahead
bx-draw-behind
bx-draw-inside
bx-dress
bx-dribbling
bx-dropdown
bx-dryer
bx-duck
bx-dumbbell-alt
bx-dumbbell
bx-ear-alt
bx-ear-slash
bx-ear
bx-earbuds
bx-earth
bx-ease-in-out
bx-ease-in
bx-ease-out
bx-edit-alt
bx-edit
bx-education
bx-egg-fried
bx-egg-yolk
bx-egg
bx-eject
bx-element-of
bx-empty-set
bx-enter
bx-enterprise
bx-envelope-alt
bx-envelope-open
bx-envelope
bx-equal-circle
bx-equal-square
bx-equal
bx-equalizer
bx-eraser
bx-ethernet
bx-euro
bx-ev-station
bx-expand-left
bx-expand-right
bx-explosion
bx-exposure
bx-extension
bx-eye-alt
bx-eye-big
bx-eye-closed
bx-eye-slash
bx-eye
bx-eyedropper
bx-face-alt-2
bx-face-alt-3
bx-face-alt-4
bx-face-alt
bx-face-child
bx-face-mask
bx-face
bx-factory
bx-fan
bx-fast-forward-circle
bx-fast-forward
bx-feather-alt
bx-feather-minus
bx-feather-plus
bx-feather
bx-female
bx-file-code
bx-file-cog
bx-file-detail
bx-file-heart
bx-file-minus
bx-file-plus
bx-file-report
bx-file-search
bx-file-star
bx-file-x
bx-file-zip
bx-file
bx-film-roll-alt
bx-film-roll
bx-film
bx-filter
bx-finger-down
bx-finger-left
bx-finger-right
bx-finger-swipe-down
bx-finger-swipe-left
bx-finger-swipe-right
bx-finger-swipe-up
bx-finger-touch
bx-finger-up
bx-fingerprint
bx-fire-alt
bx-fire-extinguisher
bx-fire
bx-first
bx-fish-alt
bx-fish
bx-flag-alt-2
bx-flag-alt-3
bx-flag-alt
bx-flag-chequered
bx-flag
bx-flame
bx-flask-round
bx-florist
bx-flower-alt-2
bx-flower-alt
bx-flower
bx-folder-check
bx-folder-code
bx-folder-cog
bx-folder-down-arrow
bx-folder-heart
bx-folder-minus
bx-folder-open
bx-folder-plus
bx-folder-search
bx-folder-star
bx-folder-up-arrow
bx-folder-x
bx-folder-zip
bx-folder
bx-font-color
bx-font-family
bx-food-menu
bx-food-tag
bx-football-kick
bx-football-pitch
bx-football
bx-footsteps
bx-foreground
bx-fork-knife
bx-fork-spoon
bx-fork
bx-form
bx-forward-big
bx-forward-slash-circle
bx-forward-slash-square
bx-forward-slash
bx-forward-stroke
bx-forward
bx-frame
bx-fridge
bx-fullscreen-exit
bx-fullscreen
bx-function
bx-functions
bx-future
bx-gallery-horizontal-end
bx-gallery-horizontal
bx-gallery-thumbnails
bx-gallery-vertical-end
bx-gallery-vertical
bx-gaming
bx-garage
bx-gavel
bx-gear
bx-gem-alt
bx-gem
bx-gestures
bx-ghost
bx-gift
bx-git-branch
bx-git-commit
bx-git-compare
bx-git-merge-queue
bx-git-merge
bx-git-pull-request-closed
bx-git-pull-request-draft
bx-git-pull-request
bx-git-repo-forked
bx-glasses-alt
bx-glasses
bx-globe-africa
bx-globe-alt-2
bx-globe-alt-3
bx-globe-alt
bx-globe-americas
bx-globe-antartica
bx-globe-asia
bx-globe-europe
bx-globe-oceania
bx-globe-stand
bx-globe
bx-golf-ball
bx-gradient
bx-greater-than-equal
bx-greater-than
bx-grid-9
bx-grid-circle-diagonal-left
bx-grid-circle-diagonal-right
bx-grid-circle-plus
bx-grid-circle
bx-grid-column-left
bx-grid-column-right
bx-grid-lines-3
bx-grid-lines
bx-grid-plus
bx-grid-row-bottom
bx-grid-row-top
bx-grid-search
bx-grid
bx-groceries
bx-group-alt
bx-group
bx-guitar-amp
bx-hail
bx-hand-rock
bx-hand
bx-handheld-alt-2
bx-handheld-alt
bx-handheld
bx-handshake
bx-hanger
bx-happy-alt
bx-happy-beaming
bx-happy-heart-eyes
bx-happy
bx-hard-drive
bx-hard-hat
bx-hashtag
bx-hdmi
bx-head
bx-heading-1
bx-heading-2
bx-heading-3
bx-heading
bx-headphone-alt-2
bx-headphone-alt
bx-headphone-mic
bx-headphone
bx-heart-break
bx-heart-circle
bx-heart-half
bx-heart-plus
bx-heart-square
bx-heart
bx-heat-wave
bx-helmet
bx-help-circle
bx-help-octagon
bx-hexagon
bx-high-speed-train
bx-highlight
bx-highlights
bx-hinduism
bx-history
bx-home-add
bx-home-alt-2
bx-home-alt-3
bx-home-alt
bx-home-circle
bx-home-heart
bx-home
bx-honey
bx-horizon-sea
bx-horizontal-align-center
bx-horizontal-align-left
bx-horizontal-align-right
bx-horizontal-center
bx-horizontal-distribute-center
bx-horizontal-distribute-left
bx-horizontal-distribute-right
bx-horizontal-left
bx-horizontal-right
bx-horizontal-spacing
bx-hospital
bx-hot-tub-water
bx-hot-tub
bx-hot
bx-hourglass
bx-hurricane
bx-icecream
bx-iframe
bx-image-alt
bx-image-circle
bx-image-landscape
bx-image-no-background
bx-image-plus
bx-image-portrait
bx-image-sparkle
bx-image
bx-images
bx-inbox
bx-incognito
bx-infinite
bx-info-circle
bx-info-octagon
bx-info-shield
bx-info-square
bx-inner-shadow
bx-institution
bx-integral
bx-intellect
bx-invert-adjust
bx-invert
bx-islam
bx-island
bx-italic
bx-joystick-alt-2
bx-joystick-alt
bx-joystick-button-alt
bx-joystick-button
bx-joystick
bx-judaism
bx-key-alt
bx-key
bx-keyboard
bx-keyframe-ease-in
bx-keyframe-ease-out
bx-keyframe-easy-ease
bx-keyframe-hold-ease-in
bx-keyframe-hold-ease-out
bx-keyframe-hold-linear-in
bx-keyframe-hold-linear-out
bx-keyframe
bx-knife
bx-lambda
bx-landmark
bx-laptop-alt
bx-laptop
bx-lasso
bx-last
bx-laugh
bx-laurel-wreath-left
bx-laurel-wreath-right
bx-laurel-wreath
bx-law
bx-layers-alt
bx-layers-down-left
bx-layers-down-right
bx-layers-minus-alt
bx-layers-plus-alt
bx-layers
bx-layout-check
bx-layout-minus
bx-layout-plus
bx-layout-search
bx-layout
bx-leaf-alt
bx-leaf
bx-left-indent
bx-lemon
bx-less-than-equal
bx-less-than
bx-letter-spacing-alt
bx-letter-spacing
bx-light-bulb-alt-2
bx-light-bulb-alt
bx-light-bulb-on
bx-light-bulb
bx-like
bx-line-chart-square
bx-line-spacing-alt
bx-line-spacing
bx-link-alt
bx-link-break
bx-link
bx-lira
bx-list-minus
bx-list-music
bx-list-ol
bx-list-play
bx-list-plus
bx-list-square
bx-list-ul-square
bx-list-ul
bx-list-x
bx-list
bx-loader-dots
bx-loader-lines-alt
bx-loader-lines
bx-location-alt-2
bx-location-alt
bx-location-blank
bx-location-check
bx-location-pin
bx-location-plus
bx-location-x
bx-location
bx-lock-keyhole-open-alt
bx-lock-keyhole-open
bx-lock-keyhole
bx-lock-open-alt
bx-lock-open
bx-lock
bx-lotion
bx-low-vision
bx-lowercase
bx-luggage
bx-lungs
bx-magic-wand
bx-magnet
bx-mail-open
bx-male
bx-man-woman
bx-man
bx-map
bx-margin-bottom
bx-margin-left
bx-margin-right
bx-margin-top
bx-martini
bx-mask
bx-math-alt
bx-math
bx-maximize
bx-meat
bx-medal-alt-2
bx-medal-alt
bx-medal-star-alt-2
bx-medal-star-alt
bx-medal-star
bx-medal
bx-medical-flask
bx-medical-kit
bx-megaphone-alt
bx-megaphone
bx-meh-alt
bx-meh-blank
bx-meh
bx-menorah
bx-menu-close
bx-menu-closer
bx-menu-filter
bx-menu-left
bx-menu-notification
bx-menu-right
bx-menu-search
bx-menu-select
bx-menu-wide
bx-menu-wider
bx-menu
bx-merge
bx-mesh
bx-message-bubble-captions
bx-message-bubble-check
bx-message-bubble-code
bx-message-bubble-detail
bx-message-bubble-dots-2
bx-message-bubble-dots
bx-message-bubble-edit
bx-message-bubble-exclamation
bx-message-bubble-heart
bx-message-bubble-image
bx-message-bubble-minus
bx-message-bubble-notification
bx-message-bubble-plus
bx-message-bubble-question-mark
bx-message-bubble-reply
bx-message-bubble-star
bx-message-bubble-x
bx-message-bubble
bx-message-captions
bx-message-check
bx-message-circle-captions
bx-message-circle-check
bx-message-circle-code
bx-message-circle-detail
bx-message-circle-dots-2
bx-message-circle-dots
bx-message-circle-edit
bx-message-circle-exclamation
bx-message-circle-heart
bx-message-circle-image
bx-message-circle-minus
bx-message-circle-notification
bx-message-circle-plus
bx-message-circle-question-mark
bx-message-circle-reply
bx-message-circle-star
bx-message-circle-x
bx-message-circle
bx-message-code
bx-message-detail
bx-message-dots-2
bx-message-dots
bx-message-edit
bx-message-exclamation
bx-message-heart
bx-message-image
bx-message-minus
bx-message-notification
bx-message-plus
bx-message-question-mark
bx-message-reply
bx-message-star
bx-message-x
bx-message
bx-meteor
bx-microchip
bx-microphone-alt-2
bx-microphone-alt
bx-microphone-big-alt
bx-microphone-big
bx-microphone-slash
bx-microphone
bx-microscope
bx-microwave-oven
bx-milk-bottle
bx-minimize
bx-minus-circle
bx-minus-plus
bx-minus-shield
bx-minus-square
bx-minus
bx-mobile-alt-2
bx-mobile-alt
bx-mobile-back-alt-2
bx-mobile-back-alt
bx-mobile-back
bx-mobile-ring
bx-mobile
bx-monitor-wallpaper
bx-monitor-wide
bx-monitor
bx-moon-crater
bx-moon-phase-0
bx-moon-phase-1
bx-moon-phase-2
bx-moon-phase-3
bx-moon-phase-4
bx-moon-phase-5
bx-moon-phase-6
bx-moon-star
bx-moon-stars
bx-moon
bx-mosque
bx-motion-alt
bx-motion
bx-motorcycle
bx-mountain-peak
bx-mountain-view
bx-mountain
bx-mouse-alt
bx-mouse
bx-moustache
bx-move-diagonal-left
bx-move-diagonal-right
bx-move-horizontal
bx-move-vertical
bx-move
bx-movie-play
bx-movie
bx-music-alt-2
bx-music-alt
bx-music-library
bx-music
bx-navigation-north
bx-network-chart
bx-network-device
bx-news
bx-newspaper
bx-night-light
bx-no-entry
bx-noise
bx-not-element-of
bx-not-equal
bx-not-subset
bx-not-superset
bx-note-book
bx-note
bx-notification-slash
bx-notification
bx-nut
bx-octopus
bx-omega
bx-option
bx-outdoor-dining
bx-outer-shadow
bx-oval-vertical
bx-oval
bx-oven
bx-owl
bx-pacifism
bx-package
bx-pacman
bx-paint-alt
bx-paint-roll
bx-paint
bx-palette
bx-pant
bx-paper-plane
bx-paperclip
bx-paragraph-spacing
bx-paragraph
bx-parallel
bx-parent-child
bx-party
bx-paste
bx-path
bx-pause-circle
bx-pause
bx-paw-print
bx-pear
bx-pen-alt
bx-pen-draw
bx-pen-edit-circle-alt
bx-pen-edit-circle
bx-pen-minus
bx-pen-plus
bx-pen
bx-pencil-circle
bx-pencil-draw
bx-pencil-edit-circle
bx-pencil-sparkles
bx-pencil-square
bx-pencil
bx-pentagon
bx-people-diversity
bx-people-handshake
bx-people-heart
bx-percentage
bx-perpendicular
bx-perspective
bx-petrol-pump
bx-pharmacy
bx-phone-book
bx-phone-forwarding
bx-phone-incoming
bx-phone-outgoing
bx-phone-plus
bx-phone-ring
bx-phone-x
bx-phone
bx-photo-album
bx-pi
bx-piano-alt
bx-piano-grand
bx-piano
bx-pickup-truck
bx-picture-in-picture-close
bx-picture-in-picture
bx-pie-chart-alt-2
bx-pie-chart-alt
bx-pie-chart
bx-piggy-bank
bx-pill-bottle-alt
bx-pill-bottle
bx-pill
bx-pin-alt
bx-pin-slash-alt
bx-pin
bx-pizza-alt
bx-pizza
bx-plane-alt
bx-plane-land
bx-plane-take-off
bx-plane
bx-planet
bx-plant-pot
bx-play-circle-alt
bx-play-circle
bx-play
bx-plug-connect
bx-plus-big
bx-plus-circle
bx-plus-minus
bx-plus-shield
bx-plus-square
bx-plus
bx-podcast
bx-polar-chart
bx-poll
bx-polygon
bx-poop
bx-popcorn
bx-popsicle
bx-pound
bx-power
bx-prawn
bx-price-tag-alt
bx-price-tag
bx-print-dollar
bx-printer
bx-proper-subset
bx-proper-superset
bx-psychology
bx-puck
bx-pulse
bx-puzzle
bx-pyramid
bx-qr-scan
bx-qr
bx-queue
bx-quote-left-alt
bx-quote-left
bx-quote-right-alt
bx-quote-right
bx-quote-single-left
bx-quote-single-right
bx-radar
bx-radiation
bx-radio-circle-marked
bx-radio-circle
bx-radio
bx-rainbow-half
bx-rainbow
bx-reading-glass
bx-reading
bx-receipt
bx-rectangle-vertical
bx-rectangle-wide
bx-rectangle
bx-recycle
bx-redo-alt
bx-redo-stroke-alt
bx-redo-stroke
bx-redo
bx-reflect-horizontal-alt
bx-reflect-horizontal
bx-reflect-vertical-alt
bx-reflect-vertical
bx-refresh-ccw-alt-dot
bx-refresh-ccw-alt
bx-refresh-ccw-dot
bx-refresh-ccw
bx-refresh-cw-alt-dot
bx-refresh-cw-alt
bx-refresh-cw-dot
bx-refresh-cw
bx-registered
bx-rename
bx-repeat-alt-2
bx-repeat-alt
bx-repeat
bx-reply-big
bx-reply-stroke
bx-reply
bx-report
bx-rewind-circle
bx-rewind
bx-rfid
bx-rgb
bx-right-angle-triangle-half
bx-right-angle-triangle
bx-right-indent
bx-road
bx-robot
bx-rocket-alt
bx-rocket
bx-rotate-ccw-10
bx-rotate-ccw-30
bx-rotate-ccw-5
bx-rotate-ccw-dot
bx-rotate-ccw
bx-rotate-cw-10
bx-rotate-cw-30
bx-rotate-cw-5
bx-rotate-cw-dot
bx-rotate-cw
bx-rotate-square-ccw
bx-rotate-square-cw
bx-route
bx-row-resize
bx-rows-3
bx-rows-4
bx-rows
bx-rss
bx-ruble
bx-rugby-ball
bx-ruler
bx-running
bx-rupee
bx-sad
bx-safe
bx-sail
bx-sandwich
bx-sapling
bx-satellite-dish-alt
bx-satellite-dish
bx-save
bx-scale
bx-scan-ar
bx-scan-barcode
bx-scan-detail
bx-scan-face
bx-scan-search
bx-scan
bx-school-bus
bx-school
bx-science
bx-scooter-delivery
bx-scooter
bx-screen-light
bx-screenshot
bx-scribble
bx-scroll
bx-sd-card
bx-sea-view
bx-seal-check
bx-seal
bx-search-alt
bx-search-big-code
bx-search-big-minus
bx-search-big-plus
bx-search-big-x
bx-search-big
bx-search-code
bx-search-minus
bx-search-plus
bx-search-x
bx-search
bx-select-all
bx-select-many
bx-select-none
bx-select
bx-self-care
bx-send-alt-2
bx-send-alt
bx-send
bx-server
bx-set-intersection
bx-set-union
bx-shadows
bx-shape-exclude-alt
bx-shape-exclude
bx-shape-intersect-alt
bx-shape-intersect
bx-shape-outline-alt
bx-shape-outline
bx-shape-rotate-ccw
bx-shape-rotate-cw
bx-shape-subtract-alt
bx-shape-subtract
bx-shape-trim-alt
bx-shape-trim
bx-shape-unite-alt
bx-shape-unite
bx-shapes-alt-2
bx-shapes-alt
bx-shapes
bx-share
bx-shekel
bx-shield-alt-2
bx-shield-alt
bx-shield-circle
bx-shield-half
bx-shield-quarter
bx-shield
bx-shinto
bx-ship
bx-shocked
bx-shopping-bag-alt
bx-shopping-bag
bx-shower
bx-shrink-left
bx-shrink-right
bx-shuffle
bx-shutter-alt
bx-shutter
bx-shuttlecock
bx-sidebar-right
bx-sidebar
bx-sigma
bx-signal-1
bx-signal-2
bx-signal-3
bx-signal-4
bx-signal-5
bx-signal-slash
bx-signature
bx-sikhism
bx-sine-wave
bx-siren-alt
bx-siren
bx-sitemap
bx-size-distort
bx-size-freeform
bx-size-uniform
bx-size-warp
bx-skateboard
bx-skip-next-circle
bx-skip-next
bx-skip-previous-circle
bx-skip-previous
bx-skirt
bx-skull
bx-sleepy
bx-slice
bx-slider-alt
bx-slider-vertical-alt
bx-slider-vertical
bx-slider
bx-slideshow
bx-smile
bx-smoke-alarm-alt-2
bx-smoke-alarm-alt
bx-smoke-alarm
bx-sneaker
bx-snowflake
bx-sock
bx-solar-panel
bx-spa
bx-spacebar
bx-spade
bx-spanner
bx-sparkle-circle
bx-sparkle-square
bx-sparkle
bx-sparkles-alt
bx-sparkles
bx-speaker
bx-sphere
bx-split
bx-spoon
bx-spray-can
bx-square-dashed-half
bx-square-dashed
bx-square-root
bx-square-rounded
bx-square-small
bx-square
bx-squircle
bx-stadium
bx-stamp
bx-star-circle
bx-star-half
bx-star-square
bx-star
bx-station
bx-steering-wheel
bx-steps-down
bx-steps-up
bx-sticker
bx-stop-circle
bx-stop
bx-stopwatch
bx-store-alt-2
bx-store-alt
bx-store
bx-strategy
bx-street-view
bx-strikethrough
bx-stroke-drawing
bx-stroke-freehand
bx-stroke-ink
bx-stroke-pen
bx-subscript
bx-subset
bx-subway
bx-sun-bright
bx-sun-dim
bx-sun-drizzle
bx-sun-fog
bx-sun-rain-wind
bx-sun-rain
bx-sun-rise
bx-sun-set
bx-sun-snow
bx-sun
bx-superscript
bx-superset
bx-surfboard
bx-sushi
bx-swap-diagonal
bx-swap-horizontal
bx-swap-vertical
bx-swatch
bx-swimming-pool
bx-swimming
bx-sword-alt
bx-sword
bx-syringe
bx-t-shirt
bx-tab
bx-table-cells-large
bx-table-cells
bx-table-columns-merge
bx-table-columns-split
bx-table-columns
bx-table-layout
bx-table-list
bx-table-rows-merge
bx-table-rows-split
bx-table-rows
bx-table-tennis
bx-table
bx-tablet
bx-tabs
bx-tachometer-alt
bx-tachometer
bx-taco
bx-tag-alt
bx-tag-x
bx-tag
bx-takeaway
bx-tape
bx-target
bx-task
bx-taxi
bx-temple
bx-tennis-ball-alt
bx-tennis-ball
bx-tennis
bx-tent
bx-terminal
bx-test-tube
bx-text-height
bx-text-underline
bx-text-width
bx-texture
bx-thermometer
bx-thought-bubble
bx-thread-roll
bx-thumb-down
bx-thumb-up
bx-thunder
bx-ticket-star
bx-ticket
bx-tickets
bx-timeline
bx-timer
bx-tiny-home
bx-tired
bx-toggle-big-left
bx-toggle-big-right
bx-toggle-left
bx-toggle-right
bx-toggles
bx-toilet-roll
bx-tooth
bx-torch
bx-tornado
bx-torus
bx-towel
bx-toy-car
bx-traffic-barrier
bx-traffic-cone
bx-train
bx-tram
bx-transgender
bx-translate
bx-transparency
bx-trash-alt
bx-trash-x
bx-trash
bx-treasure-chest
bx-tree-alt
bx-tree
bx-trees
bx-trending-down
bx-trending-up
bx-triangle-half
bx-triangle
bx-trip
bx-trophy-star
bx-trophy
bx-truck
bx-turkey-meat
bx-turn-down
bx-turn-left
bx-turn-right
bx-turn-up
bx-tv-alt
bx-tv
bx-ufo
bx-umbrella-alt
bx-umbrella
bx-underline-dashed
bx-underline-dotted
bx-underline-wavy
bx-underline
bx-undershirt
bx-undo-alt
bx-undo-stroke-alt
bx-undo-stroke
bx-undo
bx-universal-access
bx-unlink-alt
bx-unlink
bx-uppercase
bx-upside-down
bx-usb
bx-user-check
bx-user-circle
bx-user-hexagon
bx-user-id-card
bx-user-minus
bx-user-plus
bx-user-search
bx-user-square
bx-user-voice
bx-user-x
bx-user
bx-van
bx-variable
bx-vector-square
bx-vector-triangle
bx-vector
bx-vertical-align-bottom
bx-vertical-align-center
bx-vertical-align-top
bx-vertical-bottom
bx-vertical-center
bx-vertical-distribute-bottom
bx-vertical-distribute-center
bx-vertical-distribute-top
bx-vertical-spacing
bx-vertical-top
bx-vial-alt
bx-vial
bx-video-cinema
bx-video-plus
bx-video-slash
bx-video
bx-vignette
bx-virus-slash
bx-virus
bx-voicemail
bx-volleyball
bx-volume-full
bx-volume-low
bx-volume-mute
bx-volume
bx-vr-goggles
bx-vr-headset
bx-waffle
bx-walking
bx-wall
bx-wallet-alt
bx-wallet-cards
bx-wallet-note
bx-wallet
bx-warehouse
bx-washer
bx-water-drop-alt
bx-water-drop-half
bx-water-drop
bx-water-spray
bx-water
bx-watermelon
bx-waveform
bx-webcam
bx-webhook
bx-whiteboard-alt
bx-whiteboard
bx-widget-horizontal
bx-widget-small
bx-widget-vertical
bx-widget
bx-wifi-0
bx-wifi-1
bx-wifi-2
bx-wifi-slash
bx-wifi
bx-wind-alt
bx-wind-storm
bx-wind
bx-window-arrow-in
bx-window-arrow-out
bx-window-mac-alt
bx-window-mac
bx-window
bx-windows
bx-wine-alt
bx-wine
bx-wink-smile
bx-wink-tongue
bx-woman
bx-won
bx-workflow-alt
bx-workflow
bx-wrist-watch-alt
bx-wrist-watch-round-alt
bx-wrist-watch-round
bx-wrist-watch
bx-x-circle
bx-x-shield
bx-x-square
bx-x
bx-yarn-ball
bx-yen
bx-yin-yang